@@ -32,12 +32,19 @@ from .core import (
     search_by_district,
     get_states,
     get_districts,
+    get_postoffice_summary,
+)
+from .batch import (
+    BatchProcessor,
+    batch_get_states,
+    async_batch_get_states
 )
 from .exceptions import (
     PininError,
     InvalidPincodeError,
     DataNotFoundError,
     DataLoadError,
+    SummaryError
 )
 
 __version__ = "0.1.7"
@@ -59,4 +66,9 @@ __all__ = [
     "InvalidPincodeError",
     "DataNotFoundError",
     "DataLoadError",
+    "get_postoffice_summary",
+    "SummaryError",
+    "BatchProcessor",
+    "batch_get_states",
+    "async_batch_get_states"
 ]
